@@ -3,4 +3,4 @@ from .main import run, Effect, Strand, TapystryError
 from .main import Broadcast, Receive, CallFork, First, Call, Cancel, CallThread, Intercept, DebugTree, Wrapper
 from .utils import as_effect, runnable
 from .effects import Sequence, Fork, Join, Race, Subscribe, Sleep
-from .concurrency import Lock, Queue, debounced
+from .concurrency import Lock, Queue, debounced, with_lock
