@@ -1,5 +1,6 @@
 from uuid import uuid4
 from collections import deque
+import functools
 
 from tapystry import Call, Broadcast, Receive, TapystryError, as_effect
 
@@ -59,6 +60,10 @@ class Lock():
         return Release
 
 
+class QueueFullException(Exception):
+    pass
+
+
 class Queue():
     """
     A queue of items.
@@ -79,7 +84,11 @@ class Queue():
         self._counter = 0
 
     @as_effect()
-    def Put(self, item):
+    def Put(self, item, error_if_full=False):
+        """
+        Put an item into the queue
+        Blocks if the queue is full
+        """
         put_id = self._counter
         self._counter += 1
 
@@ -93,6 +102,8 @@ class Queue():
             yield Broadcast(f"put.{self._id}.{get_id}", item, immediate=True)
         else:
             if self._buffer_size >= 0 and len(self._buffer) >= self._buffer_size:
+                if error_if_full:
+                    raise QueueFullException()
                 assert len(self._buffer) == self._buffer_size
                 self._puts.append(put_id)
                 self._put_vals[put_id] = item
@@ -102,6 +113,10 @@ class Queue():
 
     @as_effect()
     def Get(self):
+        """
+        Get an item into the queue
+        Blocks if the queue is empty
+        """
         get_id = self._counter
         self._counter += 1
 
@@ -136,3 +151,18 @@ def debounced(fn):
         yield release
         return result
     return new_fn
+
+
+def with_lock(lock=None):
+    if lock is None:
+        lock = Lock()
+
+    def decorator(func):
+        @functools.wraps(func)
+        def new_func(*args, **kwargs):
+            release = yield lock.Acquire()
+            result = yield Call(func, args, kwargs)
+            yield release
+            return result
+        return new_func
+    return decorator
